Outils pour le cours PHS1903 de Polytechnique Montréal
########################################################

Documentation
==============

Installation
=============

Python
-------


Arduino
--------

Usage
======

Python
-------

Arduino
--------

Support
========

Contactez un des techniciens du cours:

* Émile Jetzer <emile.jetzer@polymtl.ca>
* Jacques Massicotte <jacques-2.massicotte@polymtl.ca>

Seules les requêtes provenant d'étudiants de la session en cours de PHS1903 ont
l'assurance d'être lues, entendues et prises en compte dans le développement du
module ou la correction de bogues. Ces requêtes doivent être faites par
courriel ou via le groupe MS Teams approprié.

Auteurs
========

Les techniciens du cours de PHS1903 sont les principaux auteurs de ce module.
Le gros du code est écrit par Émile Jetzer, suivant les conseils de Jacques
Massicotte, la coordination de Camila Rizzi et sous la responsabilité de
Caroline Boudoux et Jérémie Villeneuve.

Contribution
==============

Collaboration
--------------

Seules les contributions faites par les techniciens du cours seront prises en
compte de facto. Les contributions de l'externe n'ont aucune garantie d'être
examinées ou intégrées au projet.

Structure du projet
--------------------

Ce projet comporte une grande quantité de sous-dossiers et de fichiers de
configuration, pour faciliter l'intégration au gestionnaires de paquets Arduino
et Python. Avant de modifier les fichiers pour votre usage personnel, dans le
cadre d'un projet, ou pour contribuer au projet, assurez vous de respecter les
conventions décrites ci-dessous.

Méta-données & informations
++++++++++++++++++++++++++++

Code C++ pour Arduino
++++++++++++++++++++++

Code Python
++++++++++++

Documentation
++++++++++++++


License
=========

Citations
==========

Références
===========

État du projet
===============

Ce projet est en développement actif en préparation à la session d'automne
2026. La version 2 sera finalisée pendant l'été 2026, et vous ne devriez pas
utiliser ce module ou assumer sa fiabilité d'ici là.
